icsemantic.catalog.criteria.synonym

Package platecom :: Package ontocatalog :: Package criteria :: Module synonym |
[hide private]
[frames] | no frames]

# Module synonym

source code

A friendly criterion for ATTopic that matches the SearchableSynonymousText index parameters.

Classes | [hide private]
| ATSynonymCriterion A synonym text criterion

Variables | [hide private]
| ATSynonymCriterionSchema = `ATSimpleStringCriterionSchema`